#[repr(u8)]pub enum Girn {
Show 16 variants
GIRN_0 = 0,
GIRN_1 = 1,
_RESERVED_2 = 2,
_RESERVED_3 = 3,
_RESERVED_4 = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
_RESERVED_8 = 8,
_RESERVED_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
GIRN_0 = 0
MUA General Interrupt n is not requested to the MUB (default).
GIRN_1 = 1
MUA General Interrupt n is requested to the MUB.
_RESERVED_2 = 2
_RESERVED_3 = 3
_RESERVED_4 = 4
_RESERVED_5 = 5
_RESERVED_6 = 6
_RESERVED_7 = 7
_RESERVED_8 = 8
_RESERVED_9 = 9
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
_RESERVED_f = 15
Implementations